function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var formik = require('formik');
var propTypes = require('prop-types');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var renderError = function renderError(showErrorWhenNotFocused, error, formik, name) {
  if (!showErrorWhenNotFocused) {
    return error && formik.touched[name] && /*#__PURE__*/React__default.createElement("div", {
      "data-test": "error"
    }, error);
  }

  return error && /*#__PURE__*/React__default.createElement("div", null, error);
};

function TextField(_ref) {
  var name = _ref.name,
      label = _ref.label,
      value = _ref.value,
      onChange = _ref.onChange,
      error = _ref.error,
      showErrorWhenNotFocused = _ref.showErrorWhenNotFocused,
      _ref$formik = _ref.formik,
      formik = _ref$formik === void 0 ? {} : _ref$formik,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      rest = _objectWithoutPropertiesLoose(_ref, ["name", "label", "value", "onChange", "error", "showErrorWhenNotFocused", "formik", "type"]);

  return /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("label", {
    htmlFor: name
  }, label), /*#__PURE__*/React__default.createElement("input", _extends({
    name: name,
    label: label,
    id: name,
    value: value,
    onChange: onChange,
    type: type,
    onBlur: !showErrorWhenNotFocused ? formik.handleBlur : function () {}
  }, rest)), renderError(showErrorWhenNotFocused, error, formik, name));
}

TextField.propTypes = {
  name: propTypes.string.isRequired,
  label: propTypes.string.isRequired,
  type: propTypes.string,
  error: propTypes.string,
  value: propTypes.oneOfType([propTypes.string, propTypes.number, propTypes.instanceOf(Date)]).isRequired,
  onChange: propTypes.func.isRequired,
  formik: propTypes.object,
  showErrorWhenNotFocused: propTypes.bool
};

function Textarea(_ref) {
  var name = _ref.name,
      label = _ref.label,
      value = _ref.value,
      onChange = _ref.onChange,
      error = _ref.error,
      showErrorWhenNotFocused = _ref.showErrorWhenNotFocused,
      _ref$formik = _ref.formik,
      formik = _ref$formik === void 0 ? {} : _ref$formik,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      rest = _objectWithoutPropertiesLoose(_ref, ["name", "label", "value", "onChange", "error", "showErrorWhenNotFocused", "formik", "type"]);

  return /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("label", {
    htmlFor: name
  }, label), /*#__PURE__*/React__default.createElement("textarea", _extends({
    name: name,
    label: label,
    id: name,
    value: value,
    onChange: onChange,
    type: type,
    onBlur: !showErrorWhenNotFocused ? formik.handleBlur : function () {}
  }, rest)), renderError(showErrorWhenNotFocused, error, formik, name));
}

Textarea.propTypes = {
  name: propTypes.string.isRequired,
  label: propTypes.string.isRequired,
  type: propTypes.string,
  error: propTypes.string,
  value: propTypes.oneOfType([propTypes.string, propTypes.number, propTypes.instanceOf(Date)]).isRequired,
  onChange: propTypes.func.isRequired,
  formik: propTypes.object,
  showErrorWhenNotFocused: propTypes.bool
};

function Select(_ref) {
  var name = _ref.name,
      label = _ref.label,
      value = _ref.value,
      onChange = _ref.onChange,
      error = _ref.error,
      showErrorWhenNotFocused = _ref.showErrorWhenNotFocused,
      _ref$formik = _ref.formik,
      formik = _ref$formik === void 0 ? {} : _ref$formik,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      rest = _objectWithoutPropertiesLoose(_ref, ["name", "label", "value", "onChange", "error", "showErrorWhenNotFocused", "formik", "options"]);

  return /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement("label", {
    htmlFor: name
  }, label), /*#__PURE__*/React__default.createElement("select", _extends({
    "data-test": "control",
    id: name,
    value: value,
    name: name,
    onChange: onChange
  }, rest), /*#__PURE__*/React__default.createElement("option", {
    "data-test": "option",
    value: ""
  }), options.map(function (_ref2, index) {
    var id = _ref2.id,
        label = _ref2.label;
    return /*#__PURE__*/React__default.createElement("option", {
      value: id,
      key: index
    }, label);
  })), renderError(showErrorWhenNotFocused, error, formik, name));
}

Select.propTypes = {
  name: propTypes.string.isRequired,
  label: propTypes.string.isRequired,
  value: propTypes.oneOfType([propTypes.string, propTypes.number]).isRequired,
  options: propTypes.arrayOf(propTypes.shape({
    id: propTypes.oneOfType([propTypes.string, propTypes.number]).isRequired,
    label: propTypes.oneOfType([propTypes.string, propTypes.number]).isRequired
  })).isRequired,
  onChange: propTypes.func.isRequired,
  formik: propTypes.object,
  showErrorWhenNotFocused: propTypes.bool,
  error: propTypes.string
};

function FormContainer(_ref) {
  var initialValues = _ref.initialValues,
      onSubmit = _ref.onSubmit,
      validationSchema = _ref.validationSchema,
      render = _ref.render;
  var formik$1 = formik.useFormik({
    initialValues: initialValues,
    onSubmit: onSubmit,
    validationSchema: validationSchema
  });

  var renderInput = function renderInput(props) {
    if (props === void 0) {
      props = {};
    }

    var _props = props,
        name = _props.name,
        label = _props.label,
        _onChange = _props.onChange,
        _props$showErrorWhenN = _props.showErrorWhenNotFocused,
        showErrorWhenNotFocused = _props$showErrorWhenN === void 0 ? false : _props$showErrorWhenN,
        rest = _objectWithoutPropertiesLoose(_props, ["name", "label", "onChange", "showErrorWhenNotFocused"]);

    var fieldProps = _extends({
      showErrorWhenNotFocused: showErrorWhenNotFocused,
      formik: formik$1,
      name: name,
      label: label,
      error: formik$1.errors[name],
      value: formik$1.values[name],
      onChange: function onChange(e) {
        formik$1.handleChange(e);
        if (_onChange) _onChange(e);
      }
    }, rest);

    return /*#__PURE__*/React__default.createElement(TextField, fieldProps);
  };

  var renderTextarea = function renderTextarea(props) {
    if (props === void 0) {
      props = {};
    }

    var _props2 = props,
        name = _props2.name,
        label = _props2.label,
        _onChange2 = _props2.onChange,
        _props2$showErrorWhen = _props2.showErrorWhenNotFocused,
        showErrorWhenNotFocused = _props2$showErrorWhen === void 0 ? false : _props2$showErrorWhen,
        rest = _objectWithoutPropertiesLoose(_props2, ["name", "label", "onChange", "showErrorWhenNotFocused"]);

    var fieldProps = _extends({
      showErrorWhenNotFocused: showErrorWhenNotFocused,
      formik: formik$1,
      name: name,
      label: label,
      error: formik$1.errors[name],
      value: formik$1.values[name],
      onChange: function onChange(e) {
        formik$1.handleChange(e);
        if (_onChange2) _onChange2(e);
      }
    }, rest);

    return /*#__PURE__*/React__default.createElement(Textarea, fieldProps);
  };

  var renderSelect = function renderSelect(props) {
    if (props === void 0) {
      props = {};
    }

    var _props3 = props,
        name = _props3.name,
        label = _props3.label,
        options = _props3.options,
        _onChange3 = _props3.onChange,
        _props3$showErrorWhen = _props3.showErrorWhenNotFocused,
        showErrorWhenNotFocused = _props3$showErrorWhen === void 0 ? false : _props3$showErrorWhen,
        rest = _objectWithoutPropertiesLoose(_props3, ["name", "label", "options", "onChange", "showErrorWhenNotFocused"]);

    var fieldProps = _extends({
      showErrorWhenNotFocused: showErrorWhenNotFocused,
      formik: formik$1,
      options: options,
      label: label,
      name: name,
      value: formik$1.values[name],
      error: formik$1.errors[name],
      onChange: function onChange(e) {
        formik$1.handleChange(e);
        if (_onChange3) _onChange3(e);
      }
    }, rest);

    return /*#__PURE__*/React__default.createElement(Select, fieldProps);
  };

  var renderBtn = function renderBtn(props) {
    if (props === void 0) {
      props = {};
    }

    var _props4 = props,
        label = _props4.label,
        _props4$type = _props4.type,
        type = _props4$type === void 0 ? 'button' : _props4$type,
        rest = _objectWithoutPropertiesLoose(_props4, ["label", "type"]);

    return /*#__PURE__*/React__default.createElement("button", _extends({
      type: type
    }, rest), label);
  };

  var renderSubmitBtn = function renderSubmitBtn(props) {
    if (props === void 0) {
      props = {};
    }

    var _props5 = props,
        label = _props5.label,
        spinner = _props5.spinner,
        rest = _objectWithoutPropertiesLoose(_props5, ["label", "spinner"]);

    return /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement("button", _extends({
      disabled: !formik$1.isValid || formik$1.isSubmitting
    }, rest, {
      type: "submit"
    }), label), spinner && formik$1.isSubmitting && spinner);
  };

  var fieldProps = function fieldProps(name) {
    return {
      name: name,
      id: name,
      value: formik$1.values[name],
      onChange: formik$1.handleChange
    };
  };

  var data = {
    formik: formik$1,
    renderInput: renderInput,
    renderTextarea: renderTextarea,
    renderSelect: renderSelect,
    renderBtn: renderBtn,
    fieldProps: fieldProps,
    renderSubmitBtn: renderSubmitBtn
  };
  return render(data);
}

FormContainer.propTypes = {
  initialValues: propTypes.object.isRequired,
  render: propTypes.func.isRequired,
  onSubmit: propTypes.func,
  validationSchema: propTypes.object
};

exports.FormContainer = FormContainer;
exports.Input = TextField;
exports.Select = Select;
exports.Textarea = Textarea;
//# sourceMappingURL=index.js.map
